normBeadStrips <-
function(x, control = NULL, transform.method= c("vst", "log2", "cubicRoot"), normalize.method=c("quantile", "rsn", "ssn", "loess", "vsn")){
if(!is(x, "LumiBatch")) {stop("This function currently only works with LumiBatch objects.")}

x.s1.indices <- as.numeric(featureNames(x)) < 1e8
x.s2.indices <- as.numeric(featureNames(x)) >= 1e8

if(any(exprs(x) < 0)){
	cat("It seems data has already been background corrected. Recommend using the raw data which was not background corrected so that background correction can be done for the two strips separately.\n")
}
else{
	if(is.null(control)) {
		cat("Data was not background corrected due to the lack of control data.\n") 
	}
	else {
		if(!is(control, "LumiBatch")) {
			stop("Control data is not a LumiBatch object.\n")
		}
		if (dim(featureData(control)@data)[2] == 1) {
			stop("The control data seems to be gene control data (summaried probe control data). Please provide probe control data.\n")
		}
		control.negative.s1 <- exprs(control)[(featureData(control)@data$TargetID == "negative") & (as.numeric(featureData(control)@data$ProbeID) < 1e8), ]
		if(any(control.negative.s1 < 0)) {stop("Negative control data contains negative values.\n")}
		control.negative.s2 <- exprs(control)[(featureData(control)@data$TargetID == "negative") & (as.numeric(featureData(control)@data$ProbeID) >= 1e8), ]
		if(any(control.negative.s2 < 0)) {stop("Negative control data contains negative values.\n")}
	
		control.negative.s1 <- apply(control.negative.s1, 2, function(y) 2^mean(log2(y)))
		control.negative.s2 <- apply(control.negative.s2, 2, function(y) 2^mean(log2(y)))
	
		cat("Background correct the first strips ...\n")
		exprs(x)[x.s1.indices] <- exprs(x)[x.s1.indices] - rep(1, sum(x.s1.indices)) %*% t(control.negative.s1)
		cat("Background correct the second strips ...\n")
		exprs(x)[x.s2.indices] <- exprs(x)[x.s2.indices] - rep(1, sum(x.s2.indices)) %*% t(control.negative.s2)
	}
}

cat("Conduct data transformation and between-array normalization for the first strips ...\n")
sink.fname <- "__sink_lumi_R_output__"
sink.flag <- FALSE
if(!file.exists(sink.fname)) {
	sink.flag <- TRUE
	sink(file=sink.fname)
}
exprs(x)[x.s1.indices, ] <- exprs(lumiN(lumiT(x[x.s1.indices, ], method=transform.method), method=normalize.method))
if(sink.flag){
	sink()
	unlink(sink.fname)
}

cat("Conduct data transformation and between-array normalization for the second strips ...\n")
sink.flag <- FALSE
if(!file.exists(sink.fname)) {
	sink.flag <- TRUE
	sink(file=sink.fname)
}
exprs(x)[x.s2.indices, ] <- exprs(lumiN(lumiT(x[x.s2.indices, ], method=transform.method), method=normalize.method))
if(sink.flag){
	sink()
	unlink(sink.fname)
}

cat("Done.\n\n")
x
}

