normbycontrol <-
function(x, control=NULL, offset=50, bgCorrectOnly=FALSE){
if(is(x, "ExpressionSet")) dat <- exprs(x)
if(is(x, "matrix")) dat <- x

if(is.null(control)){
ctrl <- x@controlData
if(nrow(ctrl) == 0) stop("Control data can not be found from the controlData slot of the data object. \n")
dat.nctrl <- ctrl[tolower(ctrl$controlType) == "negative", ]
dat.nctrl <- as.matrix(dat.nctrl[, -c(1,2)])
dat.pctrl <- ctrl[tolower(ctrl$controlType) != "negative", ]
dat.pctrl <- as.matrix(dat.pctrl[, -c(1,2)])
cat("Background mean and sd were estimated from", nrow(dat.nctrl), "negative control probes.\n")
}
else
{
if(is(control, "LumiBatch")){
    dat.nctrl <- exprs(control[tolower(featureData(control)$TargetID) == "negative", ])
    dat.pctrl <- exprs(control[tolower(featureData(control)$TargetID) != "negative", ])
    cat("Background mean and sd were estimated from", nrow(dat.nctrl), "negative control probes.\n")
}
if(is(control, "matrix")){
    dat.nctrl <- control[tolower(rownames(control)) == "negative", ]
    dat.pctrl <- control[tolower(rownames(control)) != "negative", ]
    cat("Background mean and sd were estimated from", nrow(dat.nctrl), "negative control probes.\n")
}
}

if(ncol(dat) != ncol(dat.nctrl)) stop("Control data do not have the same number of columns with expression data.")

m <- nrow(dat) 
n <- ncol(dat)
mu <- sigma <- alpha <- rep(NA, n)
z <- rbind(dat, dat.pctrl, dat.nctrl)
for(i in 1:n){
	mu[i] <- mean(dat.nctrl[, i])
	sigma[i] <- sd(dat.nctrl[, i])
	alpha[i] <- max(mean(dat[, i]) - mu[i], 10)
	z[, i] <- normexp.signal(c(mu[i], log(sigma[i]), log(alpha[i])), z[, i])
}

z <- z + offset

if(!bgCorrectOnly){
	z <- normalizeQuantiles(z)
	z <- log2(z)
}

if(is(x, "ExpressionSet")){
	at <- attributes(exprs(x))
	exprs(x) <- z[1:m, ]
	attributes(exprs(x)) <- at
	pData(x) <- cbind(pData(x), mu=mu, sigma=sigma, alpha=alpha)
	varMetadata(x)[rownames(varMetadata(x)) == "mu", ] <- "Estimated mean background intensity"
	varMetadata(x)[rownames(varMetadata(x)) == "sigma", ] <- "Estimated standard deviation of background intensities"
	varMetadata(x)[rownames(varMetadata(x)) == "alpha", ] <- "Estimated mean signal intensity"
}

if(is(x, "matrix")) {
	at <- attributes(x)
	x[] <- z[1:m,]
	attributes(x) <- at
	attr(x, "normexp") <- list(mu=mu, sigma=sigma, alpha=alpha)
}
x
}

