read.illumina <- function(targets, path=NULL, ctrlpath=NULL, File=NULL, CtrlFile=NULL, verbose=TRUE)
{
if(!is.null(File)) targets$File <- File
if(!is.null(CtrlFile)) targets$CtrlFile <- CtrlFile

fnames <- unique(targets$File)
num <- length(fnames)

fname <- fnames[1]
if (!is.null(path)) fname <- file.path(path, fname)
if(verbose) cat("\nReading file ", "\"", fname, "\"", "... ...\n", sep="")
lumiRlog <- capture.output(dat <- lumiR(fname))

nsamples <- sum(targets$File == fnames[1])
if((nsamples != ncol(dat)))  stop("Number of samples do not match. Please check the file:  ", fname, "\n")

sample.order <- grep(fnames[1], targets$File, fixed=TRUE)

if(!is.null(targets$CtrlFile)){
  ctrl.fnames <- unique(targets$CtrlFile)
  if(num != length(ctrl.fnames)) stop("Number of files containing regular probes is different from number of files containing control probes.\n")
  ctrl.fname <- ctrl.fnames[1]
  if (!is.null(ctrlpath)) ctrl.fname <- file.path(ctrlpath, ctrl.fname)
  if(verbose) cat("Reading file ", "\"", ctrl.fname, "\"", "... ...\n", sep="")
  ctrl.dat <- readallctrl(ctrl.fname)
  if(ncol(dat) != (ncol(ctrl.dat)-2)) stop("The following two files have different numbers of samples: \n", fname, "\n", ctrl.fname, "\n")
}

if(num > 1){
  for(i in 2:num){
    fname <- fnames[i]
    if (!is.null(path)) fname <- file.path(path, fname)
    if(verbose) cat("\nReading file ", "\"", fname,"\"", "... ...\n", sep="")
    lumiRlog <- capture.output(dat1 <- lumiR(fname))
    dat <- combine(dat, dat1)
    
    nsamples <- sum(targets$File == fnames[i])
    if((nsamples != ncol(dat1))) stop("Numbers of samples do not match. Please check the file:  ", fname, "\n")

    sample.order <- c(sample.order, grep(fnames[i], targets$File, fixed=TRUE))

    if(!is.null(targets$CtrlFile)){
      ctrl.fname <- ctrl.fnames[i]
      if (!is.null(ctrlpath)) ctrl.fname <- file.path(ctrlpath, ctrl.fname)
      if(verbose) cat("Reading file ", "\"", ctrl.fname, "\"", "... ...\n", sep="")
      ctrl.dat1 <- readallctrl(ctrl.fname)
      if(ncol(dat1) != (ncol(ctrl.dat1)-2)) stop("The following two files have different numbers of samples: \n", fname, "\n", ctrl.fname, "\n")
      ctrl.dat <- cbind(ctrl.dat, ctrl.dat1[, -c(1,2)])
    }   
  }
}

column.order <- rep(NA, length(targets$File))
column.order[sample.order] <- 1:length(targets$File)
dat <- dat[, column.order]
if(!is.null(targets$CtrlFile)) dat@controlData <- ctrl.dat[, c(1,2, column.order + 2)]
dat
}
