\name{normBeadStrips}
\alias{normBeadStrips}
\title{Strip-level Normalization for MouseWG-6 BeadChip}
\description{Normalize two strips separately across all the arrays for MouseWG-6 BeadChips.}
\usage{
normBeadStrips(x, control = NULL, transform.method = c("vst", "log2", "cubicRoot"), normalize.method = c("quantile", "rsn", "ssn", "loess", "vsn"))
}
\arguments{
  \item{x}{ object of class "LumiBatch" containing expression data for Illumina expression bead chips.}
  \item{control}{ object of class "LumiBatch" containing probe control data (not gene control data which summaries the probe control data).}
  \item{transform.method}{ method for transforming expression intensities. This argument will be passed onto the function "lumiT()".}
  \item{normalize.method}{ method for normalizing expression intensities between strips of same type (first strips or second strips). This argument will be passed to the function "lumiN()".}
}
\details{
This function subsets the LumiBatch object by strip and normalize first strips and second strips separately. Background correction, data transformation and between-array
normalization can all be done at strip level.
Data transformation and between-array normalization methods implemented in R/Bioconductor package lumi are utilized in this function. 
If control data is provided, a single background intensity will be estimated for each strip by log2-transforming expression intensities of negative control probes in
each strip, averaging transformed intensities and then transforming it back to the original scale. The estimated background intensity will then subtracted from
the regular probe intensities for background correction for each strip.
}
\value{This function returns a normalized LumiBatch object in which the order of probes(order of rows of the expression intensity matrix) remains unchanged.}
\author{Wei Shi and Gordon K Smyth}
\references{
Shi, W, Banerjee, A, Ritchie, ME, Gerondakis, S, and Smyth, GK (2009). Illumina WG-6 BeadChip strips should be normalized separately. \emph{BMC Bioinformatics} 10, 372.
}
\examples{
\dontrun{x <- lumiR("Your_Sample_Probe_Profile.txt")
control <- lumiR("Your_ControlProbeProfile.txt")
x1 <- normBeadStrips(x, control, transform.method="vst", normalize.method="quantile")
}
}
