\name{normbycontrol}
\alias{normbycontrol}
\alias{normexpbycontrol}
\title{Normalizing Microarray Data Using Control Probes}
\description{Uses control information to help normalize microarray data}
\usage{
normbycontrol(x, control=NULL, offset=50, bgCorrectOnly=FALSE)
normexpbycontrol(x, control=NULL, offset=50)
}
\arguments{
  \item{x}{ object of class \code{ExpressionSet} or \code{matrix} containing regular probe intensities for a series of microarrays}
  \item{control}{ object of class \code{ExpressionSet} or \code{matrix} containing intensities from control probes}
  \item{offset}{ numeric value added to intensities}
  \item{bgCorrectOnly}{ background correction only if \code{TRUE}}
  }
\details{

The background correction method implemented in \code{normbycontrol} and \code{normexpbycontrol} is the same with the normexp background correction method in the limma package except that background mean and standard deviation are estimated from the negative control probes rather than from the regular probes themselves.
The average signal intensity is estimated as the mean of intensities from regular probes minus the mean of intensities from negative control probes.
This function calls \code{\link[limma]{normexp.signal}} in the limma package to extract signal intensities for each array.
All the data including regular probe intensities, positive control probe intensities and negative control probe intensities are passed on to this function.

If \code{bgCorrectOnly} is \code{FALSE}, raw data will only be background corrected and added an \code{offset}.
Otherwise, background corrected data (with an \code{offset}) will be quantile normalized and log2 transformed.
The quantile between-array normalization will normalized data from all probes including regular probes, positive control probes and negative control probes in this function.

If \code{control} is \code{NULL}, \code{x} will be assumed to be a \code{LumiBatch} object and control data will be extracted from its \code{controlData} slot.
Otherwise, control data will be extracted from \code{control}.
If \code{control} is a \code{\link{matrix}}, its row names must indicate the type of each control probe. (see \code{\link{readallctrl}} for control probe types).
\code{readallctrl} could be used to read in control data from the control data profile output by BeadStudio.

This function assumes that microarray samples in the regular probe data and control probe data are in the same order.
}
\value{Object of class \code{ExpressionSet} or \code{matrix} containing normalized intensities for regular probes only.

Estimated mean background intensity, standard deviation of background intensities and mean signal intensity can be found in the \code{phenoData} slot of \code{ExpressionSet} object, or the attribute \code{normexp} of \code{matrix} object.
}
\references{
Shi, W, Oshlack, A, and Smyth, GK (2010). Optimizing the noise versus bias trade-off for Illumina Whole Genome Expression BeadChips. \emph{Nucleic Acids Research} 38, e204. 
}
\author{Wei Shi and Gordon K Smyth}
\seealso{neqc in the limma package}
\examples{
\dontrun{
x <- lumiR("Your_Sample_Probe_Profile.txt")
x@controlData <- readallctrl("Your_ControlProbeProfile.txt")
x1 <- normbycontrol(x)
}
}
